@@ -175,7 +175,7 @@
 #'                     label.y = 10) +
 #'   annotate(geom = "text", x = 0.55, y = 10, label = "n[i]~`=`", parse = TRUE)
 #'
-#' # We use geom_debug() to see the computed values
+#' # We use geom_debug_group() to see the computed values
 #'
 #' gginnards.installed <- requireNamespace("gginnards", quietly = TRUE)
 #' if (gginnards.installed) {
@@ -183,13 +183,13 @@
 #'
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
-#'     stat_panel_counts(geom = "debug")
+#'     stat_panel_counts(geom = "debug_group")
 #' }
 #'
 #' if (gginnards.installed) {
 #'   ggplot(my.data, aes(x, y, colour = group)) +
 #'     geom_point() +
-#'     stat_group_counts(geom = "debug")
+#'     stat_group_counts(geom = "debug_group")
 #' }
 #'
 stat_panel_counts <- function(mapping = NULL,
@@ -282,6 +282,11 @@ StatPanelCounts <-
                        }
                      }
 
+                     # returned data frame must contain a "group" column
+                     if (! "group" %in% colnames(z)) {
+                       z[["group"]] <- -1L
+                     }
+
                      if (npc.used) {
                        z$npcx <- label.x
                        z$x <- NA_real_
