@@ -16,10 +16,10 @@ test_that("numeric label gives error in geom_table", {
 })
 
 get_tb <- function() {
-  mtcars %>%
-    group_by(cyl) %>%
-    summarize(wt = mean(wt), mpg = mean(mpg)) %>%
-    ungroup() %>%
+  mtcars |>
+    group_by(cyl) |>
+    summarize(wt = mean(wt), mpg = mean(mpg)) |>
+    ungroup() |>
     mutate(
       wt = sprintf("%.2f", wt),
       mpg = sprintf("%.1f", mpg)
@@ -44,6 +44,37 @@ test_that("geom_table works as expected", {
   expect_s3_class(result, "ggplot")
 })
 
+test_that("geom_table_npc works as expected", {
+  p <- ggplot(mtcars, aes(wt, mpg, colour = factor(cyl))) +
+    geom_point()
+  tb <- get_tb()
+
+  tbbl <- tibble(x = 0.5, y = 0.5, tb = list(tb))
+  result <- expect_silent(
+    p + geom_table_npc(data = tbbl, aes(npcx = x, npcy = y, label = tb))
+  )
+  expect_s3_class(result, "ggplot")
+
+  df <- data.frame(x = 0.5, y = 0.5, tb = I(list(tb)))
+  result <- expect_silent(
+    p + geom_table_npc(data = df, aes(npcx = x, npcy = y, label = tb))
+  )
+  expect_s3_class(result, "ggplot")
+
+  df <- data.frame(x = 0.5, y = 0.5, tb = I(list(tb)))
+  result <- expect_silent(
+    p + geom_table_npc(data = df, aes(npcx = x, npcy = y, label = tb),
+                       table.hjust = 0)
+  )
+  expect_s3_class(result, "ggplot")
+
+  result <- expect_silent(
+    p + geom_table_npc(data = df, aes(npcx = x, npcy = y, label = tb),
+                       table.hjust = "center")
+  )
+  expect_s3_class(result, "ggplot")
+})
+
 # test_that("data.frame", {
 #   my.df <- data.frame(x = 1:10, y = 1:10, tb = letters[1:10])
 #   expect_warning(ggplot(my.df, aes(x, y, label = tb)) +
@@ -479,7 +510,7 @@ test_that("colour targets and alpha targets work together in geom_table", {
                                            mapping = aes(x, y, label = tb))
   )
 
-  vdiffr::expect_doppelganger("geom_table_colour_box",
+  vdiffr::expect_doppelganger("geom_table_colour_box2",
                               ggplot(my_data.tb, aes(x, y)) +
                                 geom_point() +
                                 geom_table(data = my.tb,
