@@ -12,36 +12,54 @@ test_that("stacknudge", {
     theme(legend.position = "none")
 
   vdiffr::expect_doppelganger("stack_nudge1",
-                              p + geom_text(aes(label = grp),
-                                            position = position_stacknudge(vjust = 0.5, y = 0.3))
+                              p + geom_text(
+                                aes(label = grp),
+                                position = position_stacknudge(vjust = 0.5, y = 0.3))
   )
   vdiffr::expect_doppelganger("stack_nudge2",
-                              p + geom_text_s(aes(label = grp),
-                                                   vjust = 0,
-                                            position = position_stacknudge(vjust = 0.5, y = 0.3))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0,
+                                position = position_stacknudge(vjust = 0.5, y = 0.3))
   )
   vdiffr::expect_doppelganger("stack_nudge3",
-                              p + geom_text(aes(label = grp),
-                                            hjust = 0,
-                                            position = position_stacknudge(vjust = 0, x = 0.1))
+                              p + geom_text(
+                                aes(label = grp),
+                                hjust = 0,
+                                position = position_stacknudge(vjust = 0, x = 0.1))
   )
   vdiffr::expect_doppelganger("stack_nudge4",
-                              p + geom_text(aes(label = grp),
-                                            hjust = 0, angle = 90,
-                                            position = position_stacknudge(vjust = 0, x = 0.1, y = -0.21))
+                              p + geom_text(
+                                aes(label = grp),
+                                hjust = 0, angle = 90,
+                                position = position_stacknudge(vjust = 0, x = 0.1, y = -0.21))
   )
   vdiffr::expect_doppelganger("stack_nudge5",
-                              p + geom_text_s(aes(label = grp),
-                                              vjust = 0.5,
-                                              box.padding = 0.99,
-                                              position = position_stacknudge(vjust = 0.5, y = c(0.3, -0.3)))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0.5,
+                                box.padding = 0.99,
+                                position = position_stacknudge(vjust = 0.5, y = c(0.3, -0.3)))
   )
   vdiffr::expect_doppelganger("stack_nudge6",
-                              p + geom_text_s(aes(label = grp),
-                                              vjust = 0.5,
-                                              box.padding = 0.99,
-                                              position = position_stacknudge(vjust = 0.5,
-                                                                             y = c(rep(0.3, 2), rep(-0.3, 3))))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0.5,
+                                box.padding = 0.99,
+                                position = position_stacknudge(vjust = 0.5,
+                                                               y = c(rep(0.3, 2), rep(-0.3, 3))))
+  )
+  vdiffr::expect_doppelganger("stack_nudge7",
+                              ggplot(data = df, aes(x1, x2, group = grp)) +
+                                geom_col(aes(fill = grp),
+                                         width = 0.5,
+                                         position = position_stack(reverse = TRUE)) +
+                                theme(legend.position = "none") +
+                                geom_text(
+                                  aes(label = grp),
+                                  position = position_stacknudge(vjust = 0.5,
+                                                                 y = 0.3,
+                                                                 reverse = TRUE))
   )
 })
 
@@ -88,6 +106,17 @@ test_that("fillnudge", {
                                               position = position_fillnudge(vjust = 0.5,
                                                                              y = c(rep(0.3, 2), rep(-0.3, 3))))
   )
+  vdiffr::expect_doppelganger("fill_nudge7",
+                              ggplot(data = df, aes(x1, x2, group = grp)) +
+                                geom_col(aes(fill = grp),
+                                         width = 0.5,
+                                         position = position_fill(reverse = TRUE)) +
+                                theme(legend.position = "none") +
+                                geom_text(aes(label = grp),
+                                          position = position_fillnudge(vjust = 0.5,
+                                                                        y = 0.3,
+                                                                        reverse = TRUE))
+  )
 })
 
 test_that("dodgenudge", {
@@ -104,8 +133,9 @@ test_that("dodgenudge", {
     theme(legend.position = "none")
 
   vdiffr::expect_doppelganger("dodge_nudge1",
-                              p + geom_text(aes(label = grp),
-                                            position = position_dodgenudge(width = 0.5, y = 0.1))
+                              p + geom_text(
+                                aes(label = grp),
+                                position = position_dodgenudge(width = 0.5, y = 0.1))
   )
   vdiffr::expect_doppelganger("dodge_nudge2",
                               p + geom_text(aes(label = grp),
@@ -119,22 +149,39 @@ test_that("dodgenudge", {
                                                                              direction = "split"))
   )
   vdiffr::expect_doppelganger("dodge_nudge4",
-                              p + geom_text(aes(label = grp),
-                                            hjust = "center",
-                                            position = position_dodgenudge(width = 0.5, y = -0.075,
-                                                                           direction = "split"))
+                              p + geom_text(
+                                aes(label = grp),
+                                hjust = "center",
+                                position = position_dodgenudge(width = 0.5, y = -0.075,
+                                                               direction = "split"))
   )
   # assumes the default order of factor levels
   vdiffr::expect_doppelganger("dodge_nudge5",
-                              p + geom_text(aes(label = grp),
-                                            position = position_dodgenudge(width = 0.5,
-                                                                           y = c(rep(0.1, 4), -0.1)))
+                              p + geom_text(
+                                aes(label = grp),
+                                position = position_dodgenudge(width = 0.5,
+                                                               y = c(rep(0.1, 4), -0.1)))
   )
   vdiffr::expect_doppelganger("dodge_nudge6",
                               p + geom_text(aes(label = grp),
                                             position = position_dodgenudge(width = 0.5,
                                                                            y = 0.1))
   )
+  skip_if(utils::packageVersion("ggplot2") < "4.0.0", "'ggplot2' < 4.0.0")
+  vdiffr::expect_doppelganger("dodge_nudge7",
+                              ggplot(data = df, aes(x2, x1, group = grp)) +
+                                geom_col(
+                                  aes(fill = grp),
+                                  width=0.5,
+                                  position = position_dodge(width = 0.5,
+                                                            reverse = TRUE)) +
+                                theme(legend.position = "none") +
+                                geom_text(
+                                  aes(label = grp),
+                                  position = position_dodgenudge(width = 0.5,
+                                                                 y = 0.1,
+                                                                 reverse = TRUE))
+  )
 })
 
 test_that("nudge_keep", {
@@ -149,36 +196,68 @@ test_that("nudge_keep", {
     theme(legend.position = "none")
 
   vdiffr::expect_doppelganger("nudge_keep1",
-                              p + geom_text_s(aes(label = grp),
-                                              vjust = 0, hjust = 0.5,
-                                              position = position_nudge_keep(y = 0.12))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0, hjust = 0.5,
+                                position = position_nudge_keep(y = 0.12))
   )
   vdiffr::expect_doppelganger("nudge_keep2",
-                              p + geom_text_s(aes(label = grp),
-                                              vjust = 0, hjust = "left",
-                                              position = position_nudge_keep(y = 0.12))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0, hjust = "left",
+                                position = position_nudge_keep(y = 0.12))
   )
   vdiffr::expect_doppelganger("nudge_keep3",
-                              p + geom_text_s(aes(label = grp),
-                                              vjust = 0, hjust = "inward",
-                                              position = position_nudge_keep(y = 0.12))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0, hjust = "inward",
+                                position = position_nudge_keep(y = 0.12))
   )
   vdiffr::expect_doppelganger("nudge_keep4",
-                              p + geom_text_s(aes(label = grp),
-                                               position = position_nudge_keep(y = 0.12))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                position = position_nudge_keep(y = 0.12))
   )
   vdiffr::expect_doppelganger("nudge_keep5",
-                              p + geom_text_s(aes(label = grp),
-                                              position = position_nudge_keep(y = c(rep(0.12, 4), -0.12)))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                position = position_nudge_keep(y = c(rep(0.12, 4), -0.12)))
   )
   vdiffr::expect_doppelganger("nudge_keep6",
-                              p + geom_text_s(aes(label = grp),
-                                              position = position_nudge_keep(y = c(rep(0.12, 4), -0.12),
-                                                                             obey_grouping = TRUE))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                position = position_nudge_keep(y = c(rep(0.12, 4), -0.12),
+                                                               obey_grouping = TRUE))
   )
   vdiffr::expect_doppelganger("nudge_keep7",
-                              p + geom_text_s(aes(label = grp),
-                                              position = position_nudge_keep(y = c(0.12, -0.12)))
+                              p + geom_text_s(
+                                aes(label = grp),
+                                position = position_nudge_keep(y = c(0.12, -0.12)))
+  )
+})
+
+test_that("nudge_keep works with duration", {
+  df <- data.frame(x1 = lubridate::as.duration(c(1, 2, 1, 3, -1)),
+                   x2 = c("a", "b", "c", "d", "e"),
+                   grp = c("some long name", "other name", "some name",
+                           "another name", "some long name"))
+
+  p <-
+    ggplot(data = df, aes(x2, x1, group = grp)) +
+    geom_col(aes(fill = grp)) +
+    theme(legend.position = "none")
+
+  vdiffr::expect_doppelganger("nudge_keep_duration1",
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0, hjust = 0.5,
+                                position = position_nudge_keep(y = 0.12))
+  )
+  vdiffr::expect_doppelganger("nudge_keep_duration2",
+                              p + geom_text_s(
+                                aes(label = grp),
+                                vjust = 0, hjust = "left",
+                                position = position_nudge_keep(y = 0.12))
   )
 })
 
@@ -289,6 +368,57 @@ test_that("nudge_center", {
                                 )
 })
 
+test_that("nudge_center works with time", {
+  df <- data.frame(
+    x = lubridate::dmy("01-01-1070") + lubridate::hours(c(1,3,2,5,4,6)),
+    y = c("abc","cd","d","c","bcd","a")
+  )
+
+  vdiffr::expect_doppelganger("nudge_center_time0",
+                              ggplot(df, aes(x, y, label = y)) +
+                                geom_point() +
+                                geom_text(
+                                  position = position_nudge_center(center_y = 4,
+                                                                   x = 600, # numeric = seconds
+                                                                   y = 0.2)
+                                )
+  )
+  vdiffr::expect_doppelganger("nudge_center_time1",
+                              ggplot(df, aes(x, y, label = y)) +
+                                geom_point() +
+                                geom_text(hjust = 0, vjust = 0,
+                                          position = position_nudge_center(x = 300, # numeric = seconds
+                                                                           y = 0.07)
+                                )
+  )
+})
+
+test_that("nudge_center works with duration", {
+  df <- data.frame(
+    x = lubridate::as.duration(lubridate::hours(c(1,3,2,5,4,6))),
+    y = c("abc","cd","d","c","bcd","a")
+  )
+
+  vdiffr::expect_doppelganger("nudge_center_duration0",
+                              ggplot(df, aes(x, y, label = y)) +
+                                geom_point() +
+                                geom_text(
+                                  position = position_nudge_center(x = 300, # numeric = seconds
+                                                                   y = 0.2)
+                                ) # +
+#                               scale_x_time() # depends on package 'hms'
+  )
+  vdiffr::expect_doppelganger("nudge_center_duration1",
+                              ggplot(df, aes(x, y, label = y)) +
+                                geom_point() +
+                                geom_text(hjust = 0, vjust = 0,
+                                          position = position_nudge_center(x = 300, # numeric = seconds
+                                                                           y = 0.07)
+                                ) # +
+#                               scale_x_time() # depends on package 'hms'
+  )
+})
+
 test_that("nudge_line", {
   set.seed(16532)
   df <- data.frame(
