@@ -48,11 +48,22 @@ test_that("correct direction used", {
 
 test_that("correct reverse, vjust and x assigned", {
   position <- position_fillnudge(kept.origin = "none", vjust = 0.5, x = -0.3)
+  expect_identical(position$kept.origin, "none")
   expect_false(position$reverse)
   expect_identical(position$vjust, 0.5)
   expect_identical(position$y, 0)
   expect_identical(position$x, -0.3)
   expect_identical(position$fill, TRUE)
+  expect_type(position$compute_panel, "closure")
+  expect_type(position$compute_layer, "closure")
+  expect_type(position$setup_data, "closure")
+  expect_type(position$setup_params, "closure")
+  skip_if(condition = utils::packageVersion("ggplot2") < "4.0.0",
+          message = "'ggplot2' < 4.0.0")
+  expect_false(position$reverse)
+  expect_identical(position$required_aes, character(0))
+  expect_type(position$aesthetics, "closure")
+  expect_type(position$use_defaults, "closure")
 })
 
 test_that("warn on x or y longer than data", {
